@@ -17,19 +17,18 @@ from Products.CMFPlone import utils
 from Products.CMFCore.utils import getToolByName
 
 from plone.app.vocabularies.catalog import SearchableTextSourceBinder
-from Products.ATContentTypes.interface import IATFolder
+
+from OFS.interfaces import IFolder
 
 from plone.memoize.instance import memoize
 
-from zope.i18nmessageid import MessageFactory
-
 import random
 
-successStoryPortletMessageFactory = MessageFactory('Products.ATSuccessStory')
-_ = successStoryPortletMessageFactory
+from Products.ATSuccessStory import _
 
+from Products.ATSuccessStory.content.interfaces import  IATSuccessStoryFolder
 
-class IsuccessStoryPortlet(IPortletDataProvider):
+class ISuccessStoryPortlet(IPortletDataProvider):
     """A portlet
 
     It inherits from IPortletDataProvider because for this portlet, the
@@ -38,21 +37,19 @@ class IsuccessStoryPortlet(IPortletDataProvider):
     """
 
     header = schema.TextLine(title=_(u"Header"),
-                                  description=_(u"Portlet header"),
-                                  required=True)
+                             description=_(u"Portlet header"),
+                             required=True)
 
     searchpath = schema.Choice(title=_(u"Stories Path"),
-                                  description=_(u"Search for success stories inside this path"),
-                                  required=True,
-                                  source=SearchableTextSourceBinder({'object_provides' : IATFolder.__identifier__}))
+                               description=_(u"Search for success stories inside this path"),
+                               required=True,
+                               vocabulary=u'atss.existing_folders')
 
     number_of_stories = schema.Int(title=_(u"Number of stories"),
-                                        description=_(u"Specify how many Success Stories you want displayed at the same time in the portlet. Most commonly you will need 1."),
-                                        required=True)
+                                   description=_(u"Specify how many Success Stories you want displayed at the same time in the portlet. Most commonly you will need 1."),
+                                   required=True)
+
 
-    global_portlet = schema.Bool(title=_(u"Global"),
-                                 description=_(u"Is this a global portlet? this will cause not only to search using the search path, but to search for stories from the whole site."),
-                                 default=False)
 class Assignment(base.Assignment):
     """Portlet assignment.
     
@@ -60,24 +57,21 @@ class Assignment(base.Assignment):
     with columns.
     """
     
-    implements(IsuccessStoryPortlet)
+    implements(ISuccessStoryPortlet)
     
     # When you introduce new attributes, you need to make sure old portlets
     # also have these new attributes. You do that by adding them here.
     # Otherwise, installing a new version will break the site.
     number_of_stories = 1
-    global_portlet = False
 
     def __init__(self,
                  header='Success Stories',
                  searchpath='/',
-                 number_of_stories=1,
-                 global_portlet=False):
+                 number_of_stories=1):
 
         self.header = header
         self.searchpath = searchpath
         self.number_of_stories = number_of_stories
-        self.global_portlet = global_portlet
 
 
     @property
@@ -108,11 +102,8 @@ class Renderer(base.Renderer):
         folder_path = self.get_searchpath()
 
         if folder_path:
-            if not self.global_portlet:
-                results = self.context.portal_catalog(path = folder_path, portal_type = 'ATSuccessStory')
-            else:
-                results = self.context.portal_catalog(portal_type = 'ATSuccessStory')
-
+            results = self.context.portal_catalog(path = folder_path, portal_type = 'ATSuccessStory')
+                
             if results:
                 shuffled = list(results)
                 random.shuffle(shuffled)
@@ -131,27 +122,16 @@ class Renderer(base.Renderer):
         return int(self.data.number_of_stories)
 
     @property
-    def global_portlet(self):
-        return self.data.global_portlet
+    def global_portlet(self):        
+        return self.get_searchpath() == '/'.join(self.portal.getPhysicalPath())
 
     @memoize
     def get_searchpath(self):
-        folder = self.get_search_folder()
-        if IATFolder.providedBy(folder):
-            return '/'.join(folder.getPhysicalPath())
-        else:
-            return None
+        return self.data.searchpath
         
     @memoize
     def get_search_folder(self):
-        if self.global_portlet:
-            return self.portal
-        folder_path = self.data.searchpath
-
-        if folder_path[0]=='/':
-            folder_path = folder_path[1:]
-
-        return self.portal.restrictedTraverse(folder_path, default=None)
+        return self.portal.restrictedTraverse(self.data.searchpath, default=None)
     
     def get_folder_link(self):
         return self.get_search_folder().absolute_url()
@@ -164,7 +144,7 @@ class AddForm(base.AddForm):
     zope.formlib which fields to display. The create() method actually
     constructs the assignment that is being added.
     """
-    form_fields = form.Fields(IsuccessStoryPortlet)
+    form_fields = form.Fields(ISuccessStoryPortlet)
     label = _(u"Add Success Story Portlet")
     description = _(u"This portlet displays a random success story")
     
@@ -179,6 +159,7 @@ class EditForm(base.EditForm):
     This is registered with configure.zcml. The form_fields variable tells
     zope.formlib which fields to display.
     """
-    form_fields = form.Fields(IsuccessStoryPortlet)
+    form_fields = form.Fields(ISuccessStoryPortlet)
     label = _(u"Add Success Story Portlet")
     description = _(u"This portlet displays a random success story")
+
